@@ -603,6 +603,10 @@ def meta_of_feedstock(forge_dir, config=None):
 
 
 def compute_build_matrix(meta, existing_matrix=None, channel_sources=tuple()):
+    if meta.skip():
+        # return empty version matrix if build will be skipped
+        return set()
+
     channel_sources = tuple(channel_sources)
 
     # Override what `defaults` means depending on the platform used.
@@ -645,7 +649,9 @@ def main(forge_file_directory):
     build_config.CONDA_PY = 10
 
     recipe_dir = 'recipe'
-    config = {'docker': {'image': 'condaforge/linux-anvil', 'command': 'bash'},
+    config = {'docker': {'executable': 'docker',
+                         'image': 'condaforge/linux-anvil',
+                         'command': 'bash'},
               'templates': {'run_docker_build': 'run_docker_build_matrix.tmpl'},
               'travis': {},
               'circle': {},
